@@ -30,7 +30,7 @@ use DynaLoader ();
 use Carp;
 
 use vars   qw( $VERSION @ISA );
-$VERSION = "0.51";
+$VERSION = "0.53";
 @ISA     = qw( DynaLoader );
 
 sub PV { 0 }
@@ -94,6 +94,7 @@ sub new
 	}
     $last_new_err = "";
     my $self  = {%def_attr, %{$attr}};
+    defined $\ and $self->{eol} = $\;
     bless $self, $class;
     defined $self->{types} and $self->types ($self->{types});
     $self;
@@ -416,15 +417,15 @@ sub column_names
     if (@keys == 1 && ref $keys[0] eq "ARRAY") {
 	@keys = @{$keys[0]};
 	}
-    elsif (join "", map { defined $_ ? ref $_ : "UNDEF" } @keys) {
+    elsif (join "", map { defined $_ ? ref $_ : "" } @keys) {
 	croak ($self->SetDiag (3001));
 	}
 
-    $self->{_is_bound} && @keys != $self->{_is_bound} and
+    $self->{_BOUND_COLUMNS} && @keys != @{$self->{_BOUND_COLUMNS}} and
 	croak ($self->SetDiag (3003));
 
-    $self->{_COLUMN_NAMES} = [ @keys ];
-    @keys;
+    $self->{_COLUMN_NAMES} = [ map { defined $_ ? $_ : "\cAUNDEF\cA" } @keys ];
+    @{$self->{_COLUMN_NAMES}};
     } # column_names
 
 sub bind_columns
@@ -445,7 +446,7 @@ sub bind_columns
     $self->_set_attr_N ("_is_bound", scalar @refs);
     $self->{_BOUND_COLUMNS} = [ @refs ];
     @refs;
-    } # column_names
+    } # bind_columns
 
 sub getline_hr
 {
@@ -990,6 +991,16 @@ single array_ref, so you can pass C<getline ()>
 
   $csv->column_names ($csv->getline ($io));
 
+C<column_names ()> does B<no> checking on duplicates at all, which might
+lead to unwanted results. Undefined entries will be replaced with the
+string C<"\cAUNDEF\cA">, so
+
+  $csv->column_names (undef, "", "name", "name");
+  $hr = $csv->getline_hr ($io);
+
+Will set C<$hr->{"\cAUNDEF\cA"}> to the 1st field, C<$hr->{""}> to the
+2nd field, and C<$hr->{name}> to the 4th field, discarding the 2rd field.
+
 C<column_names ()> croaks on invalid arguments.
 
 =head2 bind_columns
@@ -1172,25 +1183,6 @@ as the API may change in future releases.
 
 =head1 EXAMPLES
 
-An example for creating CSV files:
-
-  my $csv = Text::CSV_XS->new;
-
-  open my $csv_fh, ">", "hello.csv" or die "hello.csv: $!";
-
-  my @sample_input_fields = (
-      'You said, "Hello!"',   5.67,
-      '"Surely"',   '',   '3.14159');
-  if ($csv->combine (@sample_input_fields)) {
-      my $string = $csv->string;
-      print $csv_fh "$string\n";
-      }
-  else {
-      my $err = $csv->error_input;
-      print "combine () failed on argument: ", $err, "\n";
-      }
-  close $csv_fh or die "hello.csv: $!";
-
 An example for parsing CSV strings:
 
   my $csv = Text::CSV_XS->new ({ keep_meta_info => 1, binary => 1 });
@@ -1210,7 +1202,27 @@ An example for parsing CSV strings:
       $csv->error_diag ();
       }
 
-Dumping the content of a database ($dbh) table ($tbl) to CSV:
+An example for creating CSV files:
+
+  my $csv = Text::CSV_XS->new;
+
+  open my $csv_fh, ">", "hello.csv" or die "hello.csv: $!";
+
+  my @sample_input_fields = (
+      'You said, "Hello!"',   5.67,
+      '"Surely"',   '',   '3.14159');
+  if ($csv->combine (@sample_input_fields)) {
+      my $string = $csv->string;
+      print $csv_fh "$string\n";
+      }
+  else {
+      my $err = $csv->error_input;
+      print "combine () failed on argument: ", $err, "\n";
+      }
+  close $csv_fh or die "hello.csv: $!";
+
+Or using the C<print ()> method, which is fater like in
+dumping the content of a database ($dbh) table ($tbl) to CSV:
 
   my $csv = Text::CSV_XS->new ({ binary => 1, eol => $/ });
   open my $fh, ">", "$tbl.csv" or die "$tbl.csv: $!";
@@ -1250,14 +1262,12 @@ internal failure, like failing to store a hash value.
 
 =item More Errors & Warnings
 
-At current, it is hard to tell where or why an error occured (if
-at all). New extensions ought to be clear and concise in reporting
-what error occurred where and why, and possibly also tell a remedy
-to the problem. error_diag is a (very) good start, but there is more
-work to be done here.
+New extensions ought to be clear and concise in reporting what error
+occurred where and why, and possibly also tell a remedy to the problem.
+error_diag is a (very) good start, but there is more work to be done here.
 
-Basic calls should croak or warn on illegal parameters. Errors
-should be documented.
+Basic calls should croak or warn on illegal parameters. Errors should be
+documented.
 
 =item eol
 
@@ -1433,19 +1443,34 @@ has been selected with the constructor.
 Sequences like C<1,"foo\rbar",2> are only allowed when the binary option
 has been selected with the constructor.
 
-=item 2023 "EIQ - QUO ..."
+=item 2023 "EIQ - QUO character not allowed
 
 Sequences like C<"foo "bar" baz",quux> and C<2023,",2008-04-05,"Foo, Bar",\n>
 will cause this error.
 
 =item 2024 "EIQ - EOF cannot be escaped, not even inside quotes"
 
+The escape character is not allowed as last character in an input stream.
+
 =item 2025 "EIQ - Loose unescaped escape"
 
+An escape character should escape only characters that need escaping. Allowing
+the escape for other characters is possible with the C<allow_loose_escape>
+attribute.
+
 =item 2026 "EIQ - Binary character inside quoted field, binary off"
 
+Binary characters are not allowed by default. Exceptions are fields that
+contain valid UTF-8, that will automatically be upgraded is the content is
+valid UTF-8. Pass the C<binary> attribute with a true value to accept binary
+characters.
+
 =item 2027 "EIQ - Quoted field not terminated"
 
+When parsing a field that started with a quotation character, the field is
+expected to be closed with a quotation charater. When the parsed line is
+exhausted before the quote is found, that field is not terminated.
+
 =item 2030 "EIF - NL char inside unquoted verbatim, binary off"
 
 =item 2031 "EIF - CR char is first char of field, not part of EOL"
